Maintainer’s guide — Invenio 3.4.0a8 documentation

# Maintainer’s guide

Following is a guide for maintainers and architects who are the responsible for maintaining one or more repositories.

- Overview
  - What is a maintainer?
  - What is an architect?
  - Becoming a maintainer
  - Stepping down as maintainer
- Setting up a repository
  - GitHub
  - Other services
  - Bootstrapping
- Releasing
  - Before you start
  - Patch-level release
  - Major/minor-level release
  - Module release
  - Invenio release
  - Manual releases
- Announcing release
- Copyright and license policy
  - License
  - Tracking copyright
  - Explicit agreement